#
# spec file for package perl-File-MimeInfo
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name File-MimeInfo
Name:           perl-File-MimeInfo
Version:        0.340.0
Release:        2.1
%define cpan_version 0.34
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Determine file types
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/MI/MICHIELB/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Encode::Locale)
BuildRequires:  perl(File::BaseDir) >= 0.03
BuildRequires:  perl(File::DesktopEntry) >= 0.04
BuildRequires:  perl(Test::More) >= 0.88
Requires:       perl(Encode::Locale)
Requires:       perl(File::BaseDir) >= 0.03
Requires:       perl(File::DesktopEntry) >= 0.04
Provides:       perl(File::MimeInfo) = %{version}
Provides:       perl(File::MimeInfo::Applications) = %{version}
Provides:       perl(File::MimeInfo::Magic) = %{version}
Provides:       perl(File::MimeInfo::Rox) = %{version}
%undefine       __perllib_provides
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  shared-mime-info
Requires:       shared-mime-info
Requires:       perl(File::BaseDir) >= 0.03
# MANUAL END

%description
This module can be used to determine the mime type of a file. It tries to
implement the freedesktop specification for a shared MIME database.

For this module shared-mime-info-spec 0.13 was used.

This package only uses the globs file. No real magic checking is used. The
File::MimeInfo::Magic package is provided for magic typing.

If you want to determine the mimetype of data in a memory buffer you should
use File::MimeInfo::Magic in combination with IO::Scalar.

This module loads the various data files when needed. If you want to hash
data earlier see the 'rehash' methods below.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes mimeopen mimetype README.md

%changelog
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Mon Dec  4 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.34
  see /usr/share/doc/packages/perl-File-MimeInfo/Changes
  0.34  2023-12-03
  - Let `mimeopen` use File::DesktopEntrys run() instead of exec() to
    make sure the application is started in the background.
    Closes https://github.com/mbeijen/File-MimeInfo/issues/53
* Wed Jul 13 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.33
  see /usr/share/doc/packages/perl-File-MimeInfo/Changes
  0.33  2022-07-12
  - Fix uninitialized value warning in File::MimeInfo::Applications,
    provided by SPFabGerman
* Mon Mar  7 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.32
  see /usr/share/doc/packages/perl-File-MimeInfo/Changes
  0.32  2022-03-06
  - Fix uninitialized values in _read_list() call, provided by mazunki
* Fri Jan  7 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.31
  see /usr/share/doc/packages/perl-File-MimeInfo/Changes
* Tue Oct 27 2020 Tina Müller <tina.mueller@suse.com>
- Add shared-mime-info dependency to cpanspec.yml
* Tue Oct 27 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.30
  see /usr/share/doc/packages/perl-File-MimeInfo/Changes
  0.30  2020-10-26
  - Added function File::MimeInfo::has_mimeinfo_database() to test if
    mimeinfo database is found
  - mimetype and mimeopen now exit with an error code if no mimeinfo database
    is found
  - Added explicit dependency on Encode::Locale
  - Properly decode parameters for `mimeopen` and `mimetype`.
    Patch provided by Nikos Skalkotos
  - Fix for undefined defaults (fixes #36).
    Reported & fix provided by Martin Vassor
  - Improved installation instructions, specifically on macOS, by
    Oleg Kostyuk & Michiel Beijen
* Mon Oct  8 2018 Dirk Stoecker <opensuse@dstoecker.de>
- Fix autogenerated changes
* Mon Aug  6 2018 coolo@suse.com
- updated to 0.29
  see /usr/share/doc/packages/perl-File-MimeInfo/Changes
  0.29  2018-08-05
  - Stable release to CPAN.
  0.28_03  2017-01-22
  - `mimeinfo --stdin` did not work. Reported by Marius Gavrilescu,
    Debian bug https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=784545
    Added minimal tests for `mimeinfo`.
  0.28_02  2016-12-17
  - Improved handling of Path::Tiny objects in default method.
  0.28_01  2016-11-29
  - Spelling fix courtesy gregor herrmann, Debian Perl group (fixes #25)
  - Added t/000-report-versions-tiny.t to find out issue with Path::Tiny file
    handles.
* Mon Nov 28 2016 coolo@suse.com
- updated to 0.28
  see /usr/share/doc/packages/perl-File-MimeInfo/Changes
  0.28  2016-11-27
  - Follow the current mime-apps-spec (fixes #8, #20)
    The current version of the mime-apps spec locates the per-user defaults
    file in `$XDG_CONFIG_HOME/mimeapps.list`. Use that location, and fall
    back to the per-system and distribution defaults as specified, with the
    previous legacy defaults file as a final fallback.
    Fix by Patrick Burroughs (Celti)
* Fri Jan 15 2016 bwiedemann@suse.com
- require File::BaseDir at runtime
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.27
  see /usr/share/doc/packages/perl-File-MimeInfo/Changes
* Tue Sep  3 2013 jw@suse.com
- pulled version 0.18 from cpan.
- perl-5142-re-syntax.patch obsoleted.
* Mon Nov 21 2011 jw@suse.com
- added perl-5142-re-syntax.patch;
  taken from https://rt.cpan.org/Public/Bug/Display.html?id=66841
  test suite now compatible to perl-5.14.2
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Sep 13 2010 jw@novell.com
- recreated specfile with cpanspec 1.78
- should now also work on SLES_10
* Tue Aug 24 2010 jw@novell.com
- added Requires: shared-mime-info
* Mon Jun 28 2010 jw@novell.com
- added Requires: perl(File::BaseDir)
* Sat Jun 26 2010 jw@novell.com
- 0.15, initial checkin
